@@ -67,8 +67,8 @@
 #![doc(
     html_logo_url = "https://raw.githubusercontent.com/tokio-rs/website/master/public/img/icons/tonic.svg"
 )]
-#![deny(broken_intra_doc_links)]
-#![doc(html_root_url = "https://docs.rs/tonic-build/0.5.2")]
+#![deny(rustdoc::broken_intra_doc_links)]
+#![doc(html_root_url = "https://docs.rs/tonic-build/0.6.0")]
 #![doc(issue_tracker_base_url = "https://github.com/hyperium/tonic/issues/")]
 #![doc(test(no_crate_inject, attr(deny(rust_2018_idioms))))]
 #![cfg_attr(docsrs, feature(doc_cfg))]
